document.addEventListener('DOMContentLoaded', () => {
  const calculateBtn = document.getElementById('calculate');
  const marketabilityInput = document.getElementById('marketability');
  const rangeValue = document.querySelector('.range-value');
  const resultsSection = document.querySelector('.results');

  // Update range value display
  marketabilityInput.addEventListener('input', (e) => {
    rangeValue.textContent = e.target.value;
  });

  calculateBtn.addEventListener('click', () => {
    const yearsLeft = parseFloat(document.getElementById('yearsLeft').value) || 0;
    const stipend = parseFloat(document.getElementById('stipend').value) || 0;
    const debt = parseFloat(document.getElementById('debt').value) || 0;
    const field = document.getElementById('field').value;
    const followers = parseFloat(document.getElementById('followers').value) || 0;
    const marketability = parseFloat(document.getElementById('marketability').value);

    // Calculate academic path metrics
    const academicMetrics = calculateAcademicMetrics(yearsLeft, stipend, debt, field);

    // Calculate content creation metrics
    const contentMetrics = calculateContentMetrics(followers, marketability);

    // Display results
    displayResults(academicMetrics, contentMetrics);
    resultsSection.classList.remove('hidden');
  });

  function calculateAcademicMetrics(years, stipend, debt, field) {
    const fieldMultipliers = {
      'stem': 1.2,
      'humanities': 0.8,
      'social': 0.9,
      'other': 1.0
    };

    const potentialSalary = 70000 * fieldMultipliers[field];
    const timeToPayoff = debt / (potentialSalary * 0.2);
    
    return {
      projectedSalary: potentialSalary,
      timeInvestment: years,
      debtPayoff: timeToPayoff,
      jobSecurity: 0.8
    };
  }

  function calculateContentMetrics(followers, marketability) {
    const baseIncome = followers * 0.1;
    const potentialGrowth = marketability * 1000;
    const volatilityRisk = (10 - marketability) / 10;

    return {
      projectedIncome: baseIncome + potentialGrowth,
      timeToEstablish: 1,
      volatility: volatilityRisk,
      flexibility: 0.9
    };
  }

  function displayResults(academic, content) {
    const academicMetricsDiv = document.querySelector('.academia .metrics');
    const contentMetricsDiv = document.querySelector('.content .metrics');
    const recommendationText = document.getElementById('recommendationText');

    academicMetricsDiv.innerHTML = `
      <p>Projected Salary: $${academic.projectedSalary.toLocaleString()}/year</p>
      <p>Time Investment: ${academic.timeInvestment} years</p>
      <p>Debt Payoff Time: ${academic.debtPayoff.toFixed(1)} years</p>
      <p>Job Security: ${(academic.jobSecurity * 100).toFixed()}%</p>
    `;

    contentMetricsDiv.innerHTML = `
      <p>Projected Income: $${content.projectedIncome.toLocaleString()}/year</p>
      <p>Time to Establish: ${content.timeToEstablish} year</p>
      <p>Market Volatility: ${(content.volatility * 100).toFixed()}%</p>
      <p>Career Flexibility: ${(content.flexibility * 100).toFixed()}%</p>
    `;

    // Generate recommendation
    const recommendation = academic.projectedSalary > content.projectedIncome
      ? "Based on the provided information, continuing your PhD program appears to offer more long-term financial stability."
      : "The content creation path shows higher income potential, but consider the higher volatility and uncertainty.";

    recommendationText.textContent = recommendation;
  }
});
